public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] mmc_core: fix data timeout for SEND_EXT_CSD
@ 2009-02-10 15:40 Adrian Hunter
  2009-02-11 13:30 ` Matt Fleming
  0 siblings, 1 reply; 12+ messages in thread
From: Adrian Hunter @ 2009-02-10 15:40 UTC (permalink / raw)
  To: Pierre Ossman; +Cc: LKML

Commit 0d3e0460f307e84904968aad6cff97bd688583d8
"MMC: CSD and CID timeout values" inadvertently broke
the timeout for the MMC command SEND_EXT_CSD.

This patch puts it back again.

Signed-off-by: Adrian Hunter <ext-adrian.hunter@nokia.com>
---
 drivers/mmc/core/mmc_ops.c |   16 ++++++++++------
 1 files changed, 10 insertions(+), 6 deletions(-)

diff --git a/drivers/mmc/core/mmc_ops.c b/drivers/mmc/core/mmc_ops.c
index 9c50e6f..418a270 100644
--- a/drivers/mmc/core/mmc_ops.c
+++ b/drivers/mmc/core/mmc_ops.c
@@ -248,12 +248,16 @@ mmc_send_cxd_data(struct mmc_card *card, struct mmc_host *host,
 
 	sg_init_one(&sg, data_buf, len);
 
-	/*
-	 * The spec states that CSR and CID accesses have a timeout
-	 * of 64 clock cycles.
-	 */
-	data.timeout_ns = 0;
-	data.timeout_clks = 64;
+	if (!mmc_host_is_spi(card->host) && opcode == MMC_SEND_EXT_CSD)
+		mmc_set_data_timeout(&data, card);
+	else {
+		/*
+		 * The spec states that CSR and CID accesses have a timeout
+		 * of 64 clock cycles (8 for SPI).
+		 */
+		data.timeout_ns = 0;
+		data.timeout_clks = 64;
+	}
 
 	mmc_wait_for_req(host, &mrq);
 
-- 
1.5.6.3

^ permalink raw reply related	[flat|nested] 12+ messages in thread

end of thread, other threads:[~2009-03-08 13:46 UTC | newest]

Thread overview: 12+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2009-02-10 15:40 [PATCH] mmc_core: fix data timeout for SEND_EXT_CSD Adrian Hunter
2009-02-11 13:30 ` Matt Fleming
2009-02-11 13:56   ` Adrian Hunter
2009-02-11 14:49     ` Adrian Hunter
2009-02-15 21:46       ` Andrew Morton
2009-02-18 20:16       ` Pierre Ossman
2009-02-19  7:33         ` Adrian Hunter
2009-02-19 11:22           ` Matt Fleming
2009-02-19 12:12             ` Adrian Hunter
2009-03-02 19:55               ` Pierre Ossman
2009-03-03 11:48                 ` Adrian Hunter
2009-03-08 13:46                   ` Pierre Ossman

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox